EditFormUiDelegate<T> class

Inheritance

Constructors

EditFormUiDelegate({required EditableModel<T> editableModel, required dynamic onSubmit(T), required bool showNonEditableFields})

Properties

disposableBag → DisposeBag
finalinherited
editableModel EditableModel<T>
final
hashCode int
The hash code for this object.
no setterinherited
onSubmit → dynamic Function(T)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNonEditableFields bool
final
uiActionsSubject → BehaviorSubject<EditFormUIAction>
finalinherited
uiStatesSubject → BehaviorSubject<EditFormUIState>
finalinherited

Methods

add(EditFormUIState uiState) → dynamic
inherited
addAction(EditFormUIAction uiAction) → dynamic
inherited
cache<T, R>(T input, R processor(T)) → R
inherited
dispose() → dynamic
inherited
init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
submit(Map<String, String> inputValues) → void
toggleShowNonEditableFields() → void
toString() String
A string representation of this object.
inherited
uiActions() Stream<EditFormUIAction>
inherited
uiStates() Stream<EditFormUIState>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited