EditFormUIStateShowLoading class

((EditFormUIStateShowLoading : EditFormUIState) showLoading){}

with data equality

Inheritance

Constructors

EditFormUIStateShowLoading()
const

Properties

asShowContent EditFormUIStateShowContent
no setterinherited
asShowContentOrNull EditFormUIStateShowContent?
no setterinherited
asShowLoading EditFormUIStateShowLoading
no setterinherited
asShowLoadingOrNull EditFormUIStateShowLoading?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isShowContent bool
no setterinherited
isShowLoading bool
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

map<R extends Object?>({required R showLoading(EditFormUIStateShowLoading showLoading), required R showContent(EditFormUIStateShowContent showContent)}) → R
inherited
mapOrNull<R extends Object?>({R showLoading(EditFormUIStateShowLoading showLoading)?, R showContent(EditFormUIStateShowContent showContent)?, R orElse(EditFormUIState editFormUIState)?}) → R?
inherited
maybeMap<R extends Object?>({R showLoading(EditFormUIStateShowLoading showLoading)?, R showContent(EditFormUIStateShowContent showContent)?, required R orElse(EditFormUIState editFormUIState)}) → R
inherited
maybeWhen<R extends Object?>({R showLoading()?, R showContent(List<FormViewModel> viewModels, bool showNonEditableFields)?, required R orElse(EditFormUIState editFormUIState)}) → R
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
partialMap({void showLoading(EditFormUIStateShowLoading showLoading)?, void showContent(EditFormUIStateShowContent showContent)?, void orElse(EditFormUIState editFormUIState)?}) → void
inherited
partialWhen({void showLoading()?, void showContent(List<FormViewModel> viewModels, bool showNonEditableFields)?, void orElse(EditFormUIState editFormUIState)?}) → void
inherited
toString() String
A string representation of this object.
override
when<R extends Object?>({required R showLoading(), required R showContent(List<FormViewModel> viewModels, bool showNonEditableFields)}) → R
inherited
whenOrNull<R extends Object?>({R showLoading()?, R showContent(List<FormViewModel> viewModels, bool showNonEditableFields)?, R orElse(EditFormUIState editFormUIState)?}) → R?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited