FormViewModel class

Constructors

FormViewModel({required String key, required FormViewModelType type, required TextInputType keyboardType, Icon? icon, required String label, String? defaultValue, List<String> selectorItems = const [], String? validator(String?)?})

Properties

defaultValue String?
final
hashCode int
The hash code for this object.
no setterinherited
icon Icon?
final
key String
final
keyboardType TextInputType
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorItems List<String>
final
type FormViewModelType
final
validator String? Function(String?)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited