EditFormUIAction class abstract
- Implementers
- Annotations
-
- @SealedManifest.new(_EditFormUIAction)
Constructors
- EditFormUIAction.doNothing()
-
constfactory
Properties
- asDoNothing → EditFormUIActionDoNothing
-
no setter
- asDoNothingOrNull → EditFormUIActionDoNothing?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDoNothing → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
R extends Object?> ({required R doNothing(EditFormUIActionDoNothing doNothing)}) → R -
mapOrNull<
R extends Object?> ({R doNothing(EditFormUIActionDoNothing doNothing)?, R orElse(EditFormUIAction editFormUIAction)?}) → R? -
maybeMap<
R extends Object?> ({R doNothing(EditFormUIActionDoNothing doNothing)?, required R orElse(EditFormUIAction editFormUIAction)}) → R -
maybeWhen<
R extends Object?> ({R doNothing()?, required R orElse(EditFormUIAction editFormUIAction)}) → R -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
partialMap(
{void doNothing(EditFormUIActionDoNothing doNothing)?, void orElse(EditFormUIAction editFormUIAction)?}) → void -
partialWhen(
{void doNothing()?, void orElse(EditFormUIAction editFormUIAction)?}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
when<
R extends Object?> ({required R doNothing()}) → R -
whenOrNull<
R extends Object?> ({R doNothing()?, R orElse(EditFormUIAction editFormUIAction)?}) → R?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited