EditFormUIActionDoNothing class

((EditFormUIActionDoNothing : EditFormUIAction) doNothing){}

with data equality

Inheritance

Constructors

EditFormUIActionDoNothing()
const

Properties

asDoNothing EditFormUIActionDoNothing
no setterinherited
asDoNothingOrNull EditFormUIActionDoNothing?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isDoNothing bool
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

map<R extends Object?>({required R doNothing(EditFormUIActionDoNothing doNothing)}) → R
inherited
mapOrNull<R extends Object?>({R doNothing(EditFormUIActionDoNothing doNothing)?, R orElse(EditFormUIAction editFormUIAction)?}) → R?
inherited
maybeMap<R extends Object?>({R doNothing(EditFormUIActionDoNothing doNothing)?, required R orElse(EditFormUIAction editFormUIAction)}) → R
inherited
maybeWhen<R extends Object?>({R doNothing()?, required R orElse(EditFormUIAction editFormUIAction)}) → R
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
partialMap({void doNothing(EditFormUIActionDoNothing doNothing)?, void orElse(EditFormUIAction editFormUIAction)?}) → void
inherited
partialWhen({void doNothing()?, void orElse(EditFormUIAction editFormUIAction)?}) → void
inherited
toString() String
A string representation of this object.
override
when<R extends Object?>({required R doNothing()}) → R
inherited
whenOrNull<R extends Object?>({R doNothing()?, R orElse(EditFormUIAction editFormUIAction)?}) → R?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited