EditFormUIState class abstract
(EditFormUIStateShowLoading showLoading){} with data equality
(EditFormUIStateShowContent showContent){List<FormViewModel> viewModels, bool showNonEditableFields} with data equality
}
- Implementers
- Annotations
-
- @SealedManifest.new(_EditFormUIState)
Constructors
-
EditFormUIState.showContent({required List<
FormViewModel> viewModels, required bool showNonEditableFields}) -
constfactory
- EditFormUIState.showLoading()
-
constfactory
Properties
- asShowContent → EditFormUIStateShowContent
-
no setter
- asShowContentOrNull → EditFormUIStateShowContent?
-
no setter
- asShowLoading → EditFormUIStateShowLoading
-
no setter
- asShowLoadingOrNull → EditFormUIStateShowLoading?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isShowContent → bool
-
no setter
- isShowLoading → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
R extends Object?> ({required R showLoading(EditFormUIStateShowLoading showLoading), required R showContent(EditFormUIStateShowContent showContent)}) → R -
mapOrNull<
R extends Object?> ({R showLoading(EditFormUIStateShowLoading showLoading)?, R showContent(EditFormUIStateShowContent showContent)?, R orElse(EditFormUIState editFormUIState)?}) → R? -
maybeMap<
R extends Object?> ({R showLoading(EditFormUIStateShowLoading showLoading)?, R showContent(EditFormUIStateShowContent showContent)?, required R orElse(EditFormUIState editFormUIState)}) → R -
maybeWhen<
R extends Object?> ({R showLoading()?, R showContent(List< FormViewModel> viewModels, bool showNonEditableFields)?, required R orElse(EditFormUIState editFormUIState)}) → R -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
partialMap(
{void showLoading(EditFormUIStateShowLoading showLoading)?, void showContent(EditFormUIStateShowContent showContent)?, void orElse(EditFormUIState editFormUIState)?}) → void -
partialWhen(
{void showLoading()?, void showContent(List< FormViewModel> viewModels, bool showNonEditableFields)?, void orElse(EditFormUIState editFormUIState)?}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
when<
R extends Object?> ({required R showLoading(), required R showContent(List< FormViewModel> viewModels, bool showNonEditableFields)}) → R -
whenOrNull<
R extends Object?> ({R showLoading()?, R showContent(List< FormViewModel> viewModels, bool showNonEditableFields)?, R orElse(EditFormUIState editFormUIState)?}) → R?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited